@@ -20,6 +20,7 @@ use std::{
 pub struct Melter {
     on_failed_resolve: FailedResolveStrategy,
     extraction: Extraction,
+    rewrite: bool,
 }
 
 impl Default for Melter {
@@ -27,6 +28,7 @@ impl Default for Melter {
         Melter {
             extraction: Extraction::InMemory,
             on_failed_resolve: FailedResolveStrategy::Ignore,
+            rewrite: true,
         }
     }
 }
@@ -49,6 +51,15 @@ impl Melter {
         self
     }
 
+    /// Set if the melter should rewrite properties to better match the plaintext format
+    ///
+    /// Setting to false will preserve binary fields and values even if they
+    /// don't make any sense in the plaintext output.
+    pub fn with_rewrite(mut self, rewrite: bool) -> Self {
+        self.rewrite = rewrite;
+        self
+    }
+
     fn convert(
         &self,
         input: &[u8],
@@ -66,6 +77,8 @@ impl Melter {
         let mut alive_data_index = 0;
         let mut unquote_list_index = 0;
         let mut ai_strategies_index = 0;
+        let mut metadata_index = 0;
+
         let tokens = tape.tokens();
 
         while let Some(token) = tokens.get(token_idx) {
@@ -84,7 +97,7 @@ impl Melter {
             match token {
                 BinaryToken::Object(_) => {
                     did_change = true;
-                    writer.extend_from_slice(b"{\r\n");
+                    writer.extend_from_slice(b"{\n");
                     depth += 1;
                     in_objects.push(in_object);
                     in_object = 1;
@@ -119,6 +132,19 @@ impl Melter {
                         ai_strategies_index = 0;
                     }
 
+                    if *x == metadata_index {
+                        metadata_index = 0;
+                        if writer.len() >= 24 && &writer[0..3] == b"SAV" {
+                            // If the header line is present, we will update
+                            // the metadata length in bytes which is the last
+                            // 8 bytes of the header line. The header line
+                            // should be 24 in length
+                            let new_size = format!("{:08x}", writer.len() - 24);
+                            let ns = new_size.as_bytes();
+                            writer[23 - ns.len()..23].copy_from_slice(ns);
+                        }
+                    }
+
                     let obj = in_objects.pop();
 
                     // The binary parser should already ensure that this will be something, but this is
@@ -178,7 +204,11 @@ impl Melter {
                     reencode_float_token = false;
                 }
                 BinaryToken::Token(x) => match TokenLookup.resolve(*x) {
-                    Some(id) if id == "is_ironman" && in_object == 1 => {
+                    Some(id)
+                        if self.rewrite
+                            && matches!(id, "ironman" | "ironman_manager")
+                            && in_object == 1 =>
+                    {
                         let skip = tokens
                             .get(token_idx + 1)
                             .map(|next_token| match next_token {
@@ -192,6 +222,10 @@ impl Melter {
                         continue;
                     }
                     Some(id) => {
+                        if in_object == 1 && id == "meta_data" {
+                            metadata_index = token_idx + 1;
+                        }
+
                         if in_object == 1 && id == "alive_data" {
                             alive_data_index = token_idx + 1;
                         }
@@ -274,7 +308,6 @@ impl Melter {
                 in_object = 2;
             } else if in_object == 2 {
                 in_object = 1;
-                writer.push(b'\r');
                 writer.push(b'\n');
             } else if in_object != 1 {
                 writer.push(b' ');
